@@ -16,10 +16,14 @@ import (
 )
 
 const (
-	changelogSource = "CHANGELOG.md"
-	changelogTarget = "website/docs/changelog.mdx"
-	docsSource      = "website/docs"
-	docsTarget      = "website/versioned_docs/version-latest"
+	changelogSource    = "CHANGELOG.md"
+	changelogTarget    = "website/docs/changelog.mdx"
+	docsSource         = "website/docs"
+	docsTarget         = "website/versioned_docs/version-latest"
+	schemaSource       = "website/static/next-schema.json"
+	schemaTarget       = "website/static/schema.json"
+	schemaTaskrcSource = "website/static/next-schema-taskrc.json"
+	schemaTaskrcTarget = "website/static/schema-taskrc.json"
 )
 
 var (
@@ -83,6 +87,10 @@ func release() error {
 		return err
 	}
 
+	if err := schema(); err != nil {
+		return err
+	}
+
 	return nil
 }
 
@@ -175,3 +183,13 @@ func docs() error {
 	}
 	return nil
 }
+
+func schema() error {
+	if err := copy.Copy(schemaSource, schemaTarget); err != nil {
+		return err
+	}
+	if err := copy.Copy(schemaTaskrcSource, schemaTaskrcTarget); err != nil {
+		return err
+	}
+	return nil
+}
