@@ -937,3 +937,44 @@ func TestVarInheritance(t *testing.T) {
 		)
 	}
 }
+
+func TestFuzzyModel(t *testing.T) {
+	t.Parallel()
+
+	NewExecutorTest(t,
+		WithName("fuzzy"),
+		WithExecutorOptions(
+			task.WithDir("testdata/fuzzy"),
+		),
+		WithTask("instal"),
+		WithRunError(),
+	)
+
+	NewExecutorTest(t,
+		WithName("not-fuzzy"),
+		WithExecutorOptions(
+			task.WithDir("testdata/fuzzy"),
+		),
+		WithTask("install"),
+	)
+}
+
+func TestIncludeChecksum(t *testing.T) {
+	t.Parallel()
+
+	NewExecutorTest(t,
+		WithName("correct"),
+		WithExecutorOptions(
+			task.WithDir("testdata/includes_checksum/correct"),
+		),
+	)
+
+	NewExecutorTest(t,
+		WithName("incorrect"),
+		WithExecutorOptions(
+			task.WithDir("testdata/includes_checksum/incorrect"),
+		),
+		WithSetupError(),
+		WithPostProcessFn(PPRemoveAbsolutePaths),
+	)
+}
