@@ -12,33 +12,49 @@ func (e *Executor) areTaskRequiredVarsSet(t *ast.Task) error {
 		return nil
 	}
 
-	var missingVars []string
-	var notAllowedValuesVars []errors.NotAllowedVar
+	var missingVars []errors.MissingVar
 	for _, requiredVar := range t.Requires.Vars {
-		value, ok := t.Vars.Get(requiredVar.Name)
+		_, ok := t.Vars.Get(requiredVar.Name)
 		if !ok {
-			missingVars = append(missingVars, requiredVar.Name)
-		} else {
-			value, isString := value.Value.(string)
-			if isString && requiredVar.Enum != nil && !slices.Contains(requiredVar.Enum, value) {
-				notAllowedValuesVars = append(notAllowedValuesVars, errors.NotAllowedVar{
-					Value: value,
-					Enum:  requiredVar.Enum,
-					Name:  requiredVar.Name,
-				})
-			}
+			missingVars = append(missingVars, errors.MissingVar{
+				Name:          requiredVar.Name,
+				AllowedValues: requiredVar.Enum,
+			})
 		}
 	}
 
 	if len(missingVars) > 0 {
-		return &errors.TaskMissingRequiredVars{
+		return &errors.TaskMissingRequiredVarsError{
 			TaskName:    t.Name(),
 			MissingVars: missingVars,
 		}
 	}
 
+	return nil
+}
+
+func (e *Executor) areTaskRequiredVarsAllowedValuesSet(t *ast.Task) error {
+	if t.Requires == nil || len(t.Requires.Vars) == 0 {
+		return nil
+	}
+
+	var notAllowedValuesVars []errors.NotAllowedVar
+	for _, requiredVar := range t.Requires.Vars {
+		varValue, _ := t.Vars.Get(requiredVar.Name)
+
+		value, isString := varValue.Value.(string)
+		if isString && requiredVar.Enum != nil && !slices.Contains(requiredVar.Enum, value) {
+			notAllowedValuesVars = append(notAllowedValuesVars, errors.NotAllowedVar{
+				Value: value,
+				Enum:  requiredVar.Enum,
+				Name:  requiredVar.Name,
+			})
+		}
+
+	}
+
 	if len(notAllowedValuesVars) > 0 {
-		return &errors.TaskNotAllowedVars{
+		return &errors.TaskNotAllowedVarsError{
 			TaskName:       t.Name(),
 			NotAllowedVars: notAllowedValuesVars,
 		}
