@@ -3,13 +3,13 @@ package task
 import (
 	"context"
 	"fmt"
-	"io"
 	"os"
 	"runtime"
 	"slices"
-	"sync"
 	"sync/atomic"
-	"time"
+
+	"golang.org/x/sync/errgroup"
+	"mvdan.cc/sh/v3/interp"
 
 	"github.com/go-task/task/v3/errors"
 	"github.com/go-task/task/v3/internal/env"
@@ -22,10 +22,6 @@ import (
 	"github.com/go-task/task/v3/internal/summary"
 	"github.com/go-task/task/v3/internal/templater"
 	"github.com/go-task/task/v3/taskfile/ast"
-
-	"github.com/sajari/fuzzy"
-	"golang.org/x/sync/errgroup"
-	"mvdan.cc/sh/v3/interp"
 )
 
 const (
@@ -34,57 +30,6 @@ const (
 	MaximumTaskCall = 1000
 )
 
-type TempDir struct {
-	Remote      string
-	Fingerprint string
-}
-
-// Executor executes a Taskfile
-type Executor struct {
-	Taskfile *ast.Taskfile
-
-	Dir         string
-	Entrypoint  string
-	TempDir     TempDir
-	Force       bool
-	ForceAll    bool
-	Insecure    bool
-	Download    bool
-	Offline     bool
-	Timeout     time.Duration
-	Watch       bool
-	Verbose     bool
-	Silent      bool
-	AssumeYes   bool
-	AssumeTerm  bool // Used for testing
-	Dry         bool
-	Summary     bool
-	Parallel    bool
-	Color       bool
-	Concurrency int
-	Interval    time.Duration
-
-	Stdin  io.Reader
-	Stdout io.Writer
-	Stderr io.Writer
-
-	Logger             *logger.Logger
-	Compiler           *Compiler
-	Output             output.Output
-	OutputStyle        ast.Output
-	TaskSorter         sort.Sorter
-	UserWorkingDir     string
-	EnableVersionCheck bool
-
-	fuzzyModel *fuzzy.Model
-
-	concurrencySemaphore chan struct{}
-	taskCallCount        map[string]*int32
-	mkdirMutexMap        map[string]*sync.Mutex
-	executionHashes      map[string]context.Context
-	executionHashesMutex sync.Mutex
-}
-
 // MatchingTask represents a task that matches a given call. It includes the
 // task itself and a list of wildcards that were matched.
 type MatchingTask struct {
@@ -352,6 +297,8 @@ func (e *Executor) runDeferred(t *ast.Task, call *Call, i int, deferredExitCode
 	}
 
 	cmd.Cmd = templater.ReplaceWithExtra(cmd.Cmd, cache, extra)
+	cmd.Task = templater.ReplaceWithExtra(cmd.Task, cache, extra)
+	cmd.Vars = templater.ReplaceVarsWithExtra(cmd.Vars, cache, extra)
 
 	if err := e.runCommand(ctx, t, call, i); err != nil {
 		e.Logger.VerboseErrf(logger.Yellow, "task: ignored error in deferred cmd: %s\n", err.Error())
@@ -467,7 +414,6 @@ func (e *Executor) FindMatchingTasks(call *Call) []*MatchingTask {
 		return matchingTasks
 	}
 	// Attempt a wildcard match
-	// For now, we can just nil check the task before each loop
 	for _, value := range e.Taskfile.Tasks.All(nil) {
 		if match, wildcards := value.WildcardMatch(call.Task); match {
 			matchingTasks = append(matchingTasks, &MatchingTask{
@@ -485,23 +431,12 @@ func (e *Executor) FindMatchingTasks(call *Call) []*MatchingTask {
 func (e *Executor) GetTask(call *Call) (*ast.Task, error) {
 	// Search for a matching task
 	matchingTasks := e.FindMatchingTasks(call)
-	switch len(matchingTasks) {
-	case 0: // Carry on
-	case 1:
+	if len(matchingTasks) > 0 {
 		if call.Vars == nil {
 			call.Vars = ast.NewVars()
 		}
 		call.Vars.Set("MATCH", ast.Var{Value: matchingTasks[0].Wildcards})
 		return matchingTasks[0].Task, nil
-	default:
-		taskNames := make([]string, len(matchingTasks))
-		for i, matchingTask := range matchingTasks {
-			taskNames[i] = matchingTask.Task.Task
-		}
-		return nil, &errors.TaskNameConflictError{
-			Call:      call.Task,
-			TaskNames: taskNames,
-		}
 	}
 
 	// If didn't find one, search for a task with a matching alias
